@@ -242,7 +242,7 @@ def _variant_vc(checkpoints):
               cwlout(["validate", "grading_summary"], ["File", "null"]),
               cwlout(["validate", "grading_plots"], {"type": "array", "items": ["File", "null"]})],
              "bcbio-vc",
-             disk={"files": 0.5}, cores=1)]
+             disk={"files": 2.0}, cores=1)]
     return vc, [["validate", "grading_summary"], ["variants", "calls"], ["variants", "gvcf"]]
 
 def _variant_ensemble(checkpoints):
@@ -312,6 +312,7 @@ def _variant_checkpoints(samples):
     checkpoints["align_split"] = not all([(dd.get_align_split_size(d) is False or
                                            not dd.get_aligner(d))
                                           for d in samples])
+    checkpoints["archive"] = any([dd.get_archive(d) for d in samples])
     checkpoints["umi"] = any([dd.get_umi_consensus(d) for d in samples])
     checkpoints["ensemble"] = any([dd.get_ensemble(d) for d in samples])
     checkpoints["cancer"] = any(dd.get_phenotype(d) in ["tumor"] for d in samples)
@@ -321,6 +322,9 @@ def _postprocess_alignment(checkpoints):
     wf = [s("prep_samples_to_rec", "multi-combined",
             [["config", "algorithm", "coverage"],
              ["rgnames", "sample"],
+             ["config", "algorithm", "background", "cnv_reference"],
+             ["config", "algorithm", "svcaller"],
+             ["config", "algorithm", "sv_regions"],
              ["config", "algorithm", "variant_regions"],
              ["reference", "fasta", "base"]],
             [cwlout("prep_samples_rec", "record")],
@@ -340,6 +344,7 @@ def _postprocess_alignment(checkpoints):
             disk={"files": 0.5}, cores=1),
           s("postprocess_alignment_to_rec", "multi-combined",
             [["align_bam"],
+             ["config", "algorithm", "archive"],
              ["config", "algorithm", "coverage_interval"],
              ["config", "algorithm", "exclude_regions"],
              ["config", "algorithm", "variant_regions"],
@@ -394,6 +399,13 @@ def _postprocess_alignment(checkpoints):
             "bcbio-vc", ["bedtools", "htslib", "gatk4"],
             disk={"files": 0.5}, cores=1)]
     out = [["regions", "sample_callable"]]
+    if checkpoints.get("archive"):
+        wf += [s("archive_to_cram", "multi-parallel",
+                 [["postprocess_alignment_rec"]],
+                 [cwlout(["archive_bam"], ["File", "null"], [".crai"])],
+                 "bcbio-vc", ["samtools"],
+                 disk={"files": 3.0})]
+        out += [["archive_bam"]]
     return wf, out
 
 def variant(samples):
@@ -515,6 +527,7 @@ def _variant_sv(checkpoints):
             disk={"files": 2.0})]
     sv_batch_inputs = [["analysis"], ["genome_build"],
                        ["work_bam_plus", "disc"], ["work_bam_plus", "sr"],
+                       ["config", "algorithm", "background", "cnv_reference"],
                        ["config", "algorithm", "tools_on"],
                        ["config", "algorithm", "tools_off"],
                        ["config", "algorithm", "svprioritize"],
@@ -528,12 +541,14 @@ def _variant_sv(checkpoints):
     steps = [s("calculate_sv_bins", "multi-combined",
                [["align_bam"], ["reference", "fasta", "base"],
                 ["metadata", "batch"], ["metadata", "phenotype"],
+                ["config", "algorithm", "background", "cnv_reference"],
                 ["config", "algorithm", "callable_regions"],
                 ["config", "algorithm", "coverage_interval"],
                 ["config", "algorithm", "exclude_regions"],
                 ["config", "algorithm", "sv_regions"],
                 ["config", "algorithm", "variant_regions"],
                 ["config", "algorithm", "variant_regions_merged"],
+                ["config", "algorithm", "seq2c_bed_ready"],
                 ["config", "algorithm", "svcaller"],
                 ["depth", "variant_regions", "regions"],
                 ["genome_resources", "variation", "lcr"], ["genome_resources", "variation", "polyx"],
@@ -552,8 +567,9 @@ def _variant_sv(checkpoints):
                [cwlout("sv_rawcoverage_rec", "record",
                        fields=[cwlout(["depth", "bins", "target"], ["File", "null"]),
                                cwlout(["depth", "bins", "antitarget"], ["File", "null"]),
+                               cwlout(["depth", "bins", "seq2c"], ["File", "null"]),
                                cwlout("inherit")])],
-               "bcbio-vc", ["mosdepth", "cnvkit"],
+               "bcbio-vc", ["mosdepth", "cnvkit", "seq2c"],
                disk={"files": 1.5}),
              s("normalize_sv_coverage", "multi-combined",
                [["sv_rawcoverage_rec"]],
@@ -576,7 +592,7 @@ def _variant_sv(checkpoints):
                 cwlout(["sv", "prioritize", "raw"], {"type": "array", "items": ["File", "null"]}),
                 cwlout(["svvalidate", "grading_summary"], ["File", "null"]),
                 cwlout(["svvalidate", "grading_plots"], {"type": "array", "items": ["File", "null"]})],
-               "bcbio-vc", disk={"files": 1.0}, cores=1)]
+               "bcbio-vc", ["bcbio-prioritize"], disk={"files": 1.0}, cores=1)]
     final_outputs = [["sv", "calls"], ["svvalidate", "grading_summary"], ["sv", "prioritize", "tsv"],
                      ["sv", "prioritize", "raw"], ["sv", "supplemental"]]
     return steps, final_outputs
